@@ -2,14 +2,17 @@
 from __future__ import unicode_literals
 
 import re
+import logging
 from datetime import datetime
 
 import six
-import praw
-from praw.errors import InvalidSubreddit
 from kitchen.text.display import wrap
 
 from . import exceptions
+from .packages import praw
+from .packages.praw.errors import InvalidSubreddit
+
+_logger = logging.getLogger(__name__)
 
 
 class Content(object):
@@ -50,46 +53,64 @@ class Content(object):
         """
         Flatten a PRAW comment tree while preserving the nested level of each
         comment via the `nested_level` attribute.
+
+        There are a couple of different ways that the input comment list can be
+        organized depending on its source:
+
+            1. Comments that are returned from the get_submission() api call.
+               In this case, the comments list will contain only top level
+               comments and replies will be attached to those comments via
+               the `comment.replies` property.
+
+            2. Comments that are returned from the comments() method on a
+               MoreComments object. In this case, the api returns all of the
+               comments and replies as a flat list. We need to sort out which
+               ones are replies to other comments by looking at the parent_id
+               parameter and checking if the id matches another comment.
+
+        In addition, there is a bug in praw where a MoreComments object that is
+        also a reply will be added below the comment as a sibling instead of
+        a child. So it is especially important that this method is robust and
+        double-checks all of the parent_id's of the comments.
+
+        Reference:
+            https://github.com/praw-dev/praw/issues/391
+
         """
 
         stack = comments[:]
         for item in stack:
             item.nested_level = root_level
 
-        retval = []
+        retval, parent_candidates = [], {}
         while stack:
             item = stack.pop(0)
 
-            # MoreComments item count should never be zero, but if it is then
-            # discard the MoreComment object. Need to look into this further.
+            # The MoreComments item count should never be zero, discard it if
+            # it is. Need to look into this further.
             if isinstance(item, praw.objects.MoreComments) and item.count == 0:
                 continue
 
-            # https://github.com/praw-dev/praw/issues/391
-            # Attach children replies to parents. Children will have the
-            # same parent_id, but with a suffix attached.
-            # E.g.
-            #   parent_comment.id = c0tprcm
-            #   comment.parent_id = t1_c0tprcm
             if item.parent_id:
-                level = None
-                # Search through previous comments for a possible parent
-                for parent in retval[::-1]:
-                    if level and parent.nested_level >= level:
-                        # Stop if we reach a sibling or a child, we know that
-                        # nothing before this point is a candidate for parent.
-                        break
-                    level = parent.nested_level
-                    if item.parent_id.endswith(parent.id):
-                        item.nested_level = parent.nested_level + 1
+                # Search the list of previous comments for a possible parent
+                # The match is based off of the parent_id parameter E.g.
+                #   parent.id = c0tprcm
+                #   child.parent_id = t1_c0tprcm
+                parent = parent_candidates.get(item.parent_id[3:])
+                if parent:
+                    item.nested_level = parent.nested_level + 1
 
-            # Otherwise, grab all of the attached replies and add them back to
-            # the list of comments to parse
+            # Add all of the attached replies to the front of the stack to be
+            # parsed separately
             if hasattr(item, 'replies'):
                 for n in item.replies:
                     n.nested_level = item.nested_level + 1
                 stack[0:0] = item.replies
 
+            # The comment is now a potential parent for the items that are
+            # remaining on the stack.
+            parent_candidates[item.id] = item
+
             retval.append(item)
         return retval
 
@@ -138,7 +159,7 @@ class Content(object):
         else:
             # Saved comments don't have a nested level and are missing a couple
             # of fields like ``submission``. As a result, we can only load a
-            # subset of fields to avoid triggering a seperate api call to load
+            # subset of fields to avoid triggering a separate api call to load
             # the full comment.
             author = getattr(comment, 'author', '[deleted]')
             stickied = getattr(comment, 'stickied', False)
@@ -146,10 +167,11 @@ class Content(object):
 
             data['type'] = 'SavedComment'
             data['level'] = None
-            data['title'] = comment.body
-            data['comments'] = ''
+            data['title'] = '[Comment] {0}'.format(comment.body)
+            data['comments'] = None
             data['url_full'] = comment._fast_permalink
             data['url'] = comment._fast_permalink
+            data['permalink'] = comment._fast_permalink
             data['nsfw'] = comment.over_18
             data['subreddit'] = six.text_type(comment.subreddit)
             data['url_type'] = 'selfpost'
@@ -304,6 +326,7 @@ class SubmissionContent(Content):
         self.max_indent_level = max_indent_level
         self.name = submission_data['permalink']
         self.order = order
+        self.query = None
         self._loader = loader
         self._submission = submission
         self._submission_data = submission_data
@@ -320,7 +343,7 @@ class SubmissionContent(Content):
         url = url.replace('https://np.', 'https://www.')
         submission = reddit.get_submission(url, comment_sort=order)
         return cls(submission, loader, indent_size, max_indent_level, order,
-            max_comment_cols)
+                   max_comment_cols)
 
     @property
     def range(self):
@@ -413,10 +436,12 @@ class SubredditContent(Content):
     list for repeat access.
     """
 
-    def __init__(self, name, submissions, loader, order=None, max_title_rows=4):
+    def __init__(self, name, submissions, loader, order=None,
+                 max_title_rows=4, query=None):
 
         self.name = name
         self.order = order
+        self.query = query
         self.max_title_rows = max_title_rows
         self._loader = loader
         self._submissions = submissions
@@ -544,7 +569,7 @@ class SubredditContent(Content):
                 raise exceptions.AccountError('Not logged in')
             else:
                 order = order or 'new'
-                submissions = reddit.user.get_submitted(sort=order, limit=None)
+                submissions = reddit.user.get_overview(sort=order, limit=None)
 
         elif resource_root == 'u' and resource == 'saved':
             if not reddit.is_oauth_session():
@@ -557,7 +582,7 @@ class SubredditContent(Content):
             order = order or 'new'
             period = period or 'all'
             redditor = reddit.get_redditor(resource)
-            submissions = redditor.get_submitted(
+            submissions = redditor.get_overview(
                 sort=order, time=period, limit=None)
 
         elif resource == 'front':
@@ -581,7 +606,8 @@ class SubredditContent(Content):
             display_name = '/r/{0}'.format(subreddit.display_name)
 
         # We made it!
-        return cls(display_name, submissions, loader, order=display_order)
+        return cls(display_name, submissions, loader, order=display_order,
+                   query=query)
 
     @property
     def range(self):
@@ -637,6 +663,7 @@ class SubscriptionContent(Content):
 
         self.name = name
         self.order = None
+        self.query = None
         self._loader = loader
         self._subscriptions = subscriptions
         self._subscription_data = []
