@@ -48,4 +48,8 @@ class TemporaryFileError(RTVError):
 
 
 class MailcapEntryNotFound(RTVError):
-    "A valid mailcap entry could not be coerced from the given url"
\ No newline at end of file
+    "A valid mailcap entry could not be coerced from the given url"
+
+
+class InvalidRefreshToken(RTVError):
+    "The refresh token is corrupt and cannot be used to login"
