@@ -14,10 +14,10 @@ import curses.ascii
 from contextlib import contextmanager
 
 import six
-import praw
 import requests
 
 from . import exceptions
+from .packages import praw
 
 
 _logger = logging.getLogger(__name__)
@@ -58,7 +58,6 @@ def curses_session():
             curses.start_color()
         except:
             _logger.warning('Curses failed to initialize color support')
-            pass
 
         # Hide the blinking cursor
         try:
@@ -644,14 +643,16 @@ class KeyMap(object):
         self.set_bindings(bindings)
 
     def set_bindings(self, bindings):
-        # Clear the keymap before applying the bindings to avoid confusion.
-        # If a user defines custom bindings in their config file, they must
-        # explicitly define ALL of the bindings.
-        self._keymap = {}
+        new_keymap = {}
         for command, keys in bindings.items():
             if not isinstance(command, Command):
                 command = Command(command)
-            self._keymap[command] = keys
+            new_keymap[command] = keys
+
+        if not self._keymap:
+            self._keymap = new_keymap
+        else:
+            self._keymap.update(new_keymap)
 
     def get(self, command):
         if not isinstance(command, Command):
@@ -695,4 +696,4 @@ class KeyMap(object):
 
         except (AttributeError, ValueError, TypeError):
             raise exceptions.ConfigError('Invalid configuration! "%s" is not a '
-                                         'valid key' % key)
\ No newline at end of file
+                                         'valid key' % key)
