@@ -3,18 +3,22 @@ from __future__ import unicode_literals
 
 import os
 import sys
-import six
 import time
 import curses
+import logging
 from functools import wraps
 
+import six
 from kitchen.text.display import textual_width
 
 from . import docs
 from .objects import Controller, Color, Command
-from .exceptions import TemporaryFileError
+from .clipboard import copy
+from .exceptions import TemporaryFileError, ProgramError
 from .__version__ import __version__
 
+_logger = logging.getLogger(__name__)
+
 
 def logged_in(f):
     """
@@ -46,6 +50,7 @@ class Page(object):
         self.content = None
         self.nav = None
         self.controller = None
+        self.copy_to_clipboard = copy
 
         self.active = True
         self._row = 0
@@ -318,6 +323,50 @@ class Page(object):
         message = 'New Messages' if inbox > 0 else 'No New Messages'
         self.term.show_notification(message)
 
+    @PageController.register(Command('COPY_PERMALINK'))
+    def copy_permalink(self):
+        """
+        Copies submission permalink to OS clipboard
+        """
+
+        data = self.get_selected_item()
+        url = data.get('permalink')
+        if url is None:
+            self.term.flash()
+            return
+
+        try:
+            self.copy_to_clipboard(url)
+        except (ProgramError, OSError) as e:
+            _logger.exception(e)
+            self.term.show_notification(
+                'Failed to copy permalink: {0}'.format(e))
+        else:
+            self.term.show_notification(
+                'Copied permalink to clipboard', timeout=1)
+
+    @PageController.register(Command('COPY_URL'))
+    def copy_url(self):
+        """
+        Copies submission url to OS clipboard
+        """
+
+        data = self.get_selected_item()
+        url = data.get('url_full')
+        if url is None:
+            self.term.flash()
+            return
+
+        try:
+            self.copy_to_clipboard(url)
+        except (ProgramError, OSError) as e:
+            _logger.exception(e)
+            self.term.show_notification(
+                'Failed to copy url: {0}'.format(e))
+        else:
+            self.term.show_notification(
+                'Copied url to clipboard', timeout=1)
+
     def clear_input_queue(self):
         """
         Clear excessive input caused by the scroll wheel or holding down a key
@@ -341,14 +390,7 @@ class Page(object):
         self._draw_content()
         self._draw_footer()
         self._add_cursor()
-        # Note: There used to be a call to stdscr.touchwin() here. However, a
-        # bug was discovered in tmux when $TERM was set to `xterm-256color`,
-        # where only part of the screen got redrawn when scrolling. The correct
-        # solution is to use `screen-256color` (which gets set automatically by
-        # tmux) but many people override ther $TERM in their tmux.conf or
-        # .bashrc file. Using clearok() instead seems to fix the problem, at
-        # the expense of slightly more expensive screen refreshes.
-        self.term.stdscr.clearok(True)
+        self.term.clear_screen()
         self.term.stdscr.refresh()
 
     def _draw_header(self):
@@ -366,6 +408,10 @@ class Page(object):
         sub_name = sub_name.replace('/r/front', 'Front Page')
         sub_name = sub_name.replace('/u/me', 'My Submissions')
         sub_name = sub_name.replace('/u/saved', 'My Saved Submissions')
+
+        query = self.content.query
+        if query:
+            sub_name = 'Searching {0}: {1}'.format(sub_name, query)
         self.term.add_line(window, sub_name, 0, 0)
 
         # Set the terminal title
