@@ -20,12 +20,17 @@ import six
 #pylint: disable=import-error
 from six.moves.urllib.parse import quote
 from kitchen.text.display import textual_width_chop
-from mailcap_fix import mailcap
 
 from . import exceptions
 from . import mime_parsers
 from .objects import LoadScreen, Color
 
+try:
+    # Fix only needed for versions prior to python 3.6
+    from mailcap_fix import mailcap
+except ImportError:
+    import mailcap
+
 try:
     # Added in python 3.4+
     from html import unescape
@@ -54,6 +59,11 @@ class Terminal(object):
         self.loader = LoadScreen(self)
         self._display = None
         self._mailcap_dict = mailcap.getcaps()
+        self._term = os.environ.get('TERM')
+
+        # This is a hack, the MIME parsers should be stateless
+        # but we need to load the imgur credentials from the config
+        mime_parsers.ImgurApiMIMEParser.CLIENT_ID = config['imgur_client_id']
 
     @property
     def up_arrow(self):
@@ -426,7 +436,7 @@ class Terminal(object):
                 except Exception as e:
                     # If Imgur decides to change its html layout, let it fail
                     # silently in the background instead of crashing.
-                    _logger.warn('parser %s raised an exception', parser)
+                    _logger.warning('parser %s raised an exception', parser)
                     _logger.exception(e)
                     raise exceptions.MailcapEntryNotFound()
                 if not content_type:
@@ -559,7 +569,10 @@ class Terminal(object):
             fp.write(data)
         _logger.info('File created: %s', filepath)
 
-        editor = os.getenv('RTV_EDITOR') or os.getenv('EDITOR') or 'nano'
+        editor = (os.getenv('RTV_EDITOR') or
+                  os.getenv('VISUAL') or
+                  os.getenv('EDITOR') or
+                  'nano')
         command = shlex.split(editor) + [filepath]
         try:
             with self.suspend():
@@ -764,3 +777,30 @@ class Terminal(object):
 
         out = '\n'.join(stack)
         return out
+    
+    def clear_screen(self):
+        """
+        In the beginning this always called touchwin(). However, a bug
+        was discovered in tmux when TERM was set to `xterm-256color`, where
+        only part of the screen got redrawn when scrolling. tmux automatically
+        sets TERM to `screen-256color`, but many people choose to override
+        this in their tmux.conf or .bashrc file which can cause issues.
+        Using clearok() instead seems to fix the problem, with the trade off
+        of slightly more expensive screen refreshes.
+               
+        Update: It was discovered that using clearok() introduced a
+        separate bug for urxvt users in which their screen flashed when
+        scrolling. Heuristics were added to make it work with as many
+        configurations as possible. It's still not perfect
+        (e.g. urxvt + xterm-256color) will screen flash, but it should
+        work in all cases if the user sets their TERM correctly.
+        
+        Reference:
+            https://github.com/michael-lazar/rtv/issues/343
+            https://github.com/michael-lazar/rtv/issues/323
+        """
+
+        if self._term != 'xterm-256color':
+            self.stdscr.touchwin()
+        else:
+            self.stdscr.clearok(True)
