@@ -3,8 +3,9 @@ from __future__ import unicode_literals
 
 import six
 
-from rtv.subreddit_page import SubredditPage
 from rtv import __version__
+from rtv.subreddit_page import SubredditPage
+from rtv.packages.praw.errors import NotFound
 
 try:
     from unittest import mock
@@ -86,6 +87,7 @@ def test_subreddit_title(subreddit_page, terminal, capsys):
 
 
 def test_subreddit_search(subreddit_page, terminal):
+    window = terminal.stdscr.subwin
 
     # Search the current subreddit
     with mock.patch.object(terminal, 'prompt_input'):
@@ -95,12 +97,31 @@ def test_subreddit_search(subreddit_page, terminal):
         assert terminal.prompt_input.called
         assert not terminal.loader.exception
 
+        # The page title should display the query
+        subreddit_page.draw()
+        title = 'Searching /r/python: search term'.encode('utf-8')
+        window.addstr.assert_any_call(0, 0, title)
+
+    # Ordering the results should preserve the query
+    window.addstr.reset_mock()
+    subreddit_page.refresh_content(order='hot')
+    subreddit_page.refresh_content(order='top-all')
+    subreddit_page.refresh_content(order='new')
+    assert subreddit_page.content.name == '/r/python'
+    assert subreddit_page.content.query == 'search term'
+    assert not terminal.loader.exception
+
     # Searching with an empty query shouldn't crash
     with mock.patch.object(terminal, 'prompt_input'):
         terminal.prompt_input.return_value = None
         subreddit_page.controller.trigger('f')
         assert not terminal.loader.exception
 
+    # Changing to a new subreddit should clear the query
+    window.addstr.reset_mock()
+    subreddit_page.refresh_content(name='/r/learnpython')
+    assert subreddit_page.content.query is None
+
 
 def test_subreddit_prompt(subreddit_page, terminal):
 
@@ -113,6 +134,34 @@ def test_subreddit_prompt(subreddit_page, terminal):
         assert not terminal.loader.exception
 
 
+def test_subreddit_prompt_submission(subreddit_page, terminal):
+
+    prompts = [
+        'comments/571dw3',
+        '///comments/571dw3',
+        '/comments/571dw3',
+        '/r/pics/comments/571dw3/',
+        'https://www.reddit.com/r/pics/comments/571dw3/at_disneyland']
+    url = 'https://www.reddit.com/comments/571dw3'
+
+    for text in prompts:
+        with mock.patch.object(subreddit_page, 'open_submission'), \
+                mock.patch.object(terminal, 'prompt_input'):
+
+            terminal.prompt_input.return_value = text
+            subreddit_page.controller.trigger('/')
+            subreddit_page.open_submission.assert_called_with(url)
+            assert not terminal.loader.exception
+
+
+def test_subreddit_prompt_submission_invalid(subreddit_page, terminal):
+
+    with mock.patch.object(terminal, 'prompt_input'):
+        terminal.prompt_input.return_value = 'comments/571dw3fakeid'
+        subreddit_page.controller.trigger('/')
+        assert isinstance(terminal.loader.exception, NotFound)
+
+
 def test_subreddit_order_top(subreddit_page, terminal):
 
     # Sort by top
@@ -272,6 +321,29 @@ def test_subreddit_open_multireddits(subreddit_page, refresh_token):
         assert loop.called
 
 
+def test_subreddit_saved(subreddit_page, refresh_token):
+
+    # Log in
+    subreddit_page.config.refresh_token = refresh_token
+    subreddit_page.oauth.authorize()
+
+    subreddit_page.refresh_content(name='/u/saved')
+    subreddit_page.draw()
+
+
+def test_subreddit_user_overview(subreddit_page, refresh_token):
+
+    # Log in
+    subreddit_page.config.refresh_token = refresh_token
+    subreddit_page.oauth.authorize()
+
+    # Pick a user that has a lot of recent comments, so we can make sure that
+    # SavedComment objects have all of the properties necessary to be drawn
+    # on the submission page.
+    subreddit_page.refresh_content(name='/u/spez')
+    subreddit_page.draw()
+
+
 def test_subreddit_draw_header(subreddit_page, refresh_token, terminal):
 
     # /r/front alias should be renamed in the header
